@@ -1333,6 +1333,9 @@ def main(argv=tuple(), tbuf=None, **kwargs):
 
     _memoryCheck("end")
 
+    # stop taskBuffer if created inside this script
+    taskBuffer.cleanup()
+
     _logger.debug("===================== end =====================")
 
 
