@@ -202,3 +202,17 @@ class SiteSpec(object):
             return items[-1]
         else:
             return None
+
+    # get bare nucleus mode
+    def bare_nucleus_mode(self):
+        mode = self.getValueFromCatchall('bareNucleus')
+        if mode in ['only', 'allow']:
+            return mode
+        return None
+
+    # get secondary nucleus
+    def secondary_nucleus(self):
+        n = self.getValueFromCatchall('secondaryNucleus')
+        if n:
+            return n
+        return None
